==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticationFlowEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
public class MapAuthenticationFlowEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity> entityFieldDelegate;
    public MapAuthenticationFlowEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAlias() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.ALIAS);
    }
    @SuppressWarnings("unchecked") @Override public void setAlias(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.ALIAS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getDescription() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.DESCRIPTION);
    }
    @SuppressWarnings("unchecked") @Override public void setDescription(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.DESCRIPTION, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getProviderId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.PROVIDER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setProviderId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.PROVIDER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isBuiltIn() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.BUILT_IN);
    }
    @SuppressWarnings("unchecked") @Override public void setBuiltIn(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.BUILT_IN, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isTopLevel() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.TOP_LEVEL);
    }
    @SuppressWarnings("unchecked") @Override public void setTopLevel(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.TOP_LEVEL, p0);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapAuthenticationFlowEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapAuthenticationFlowEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity> entityFieldDelegate;
    public MapAuthenticationFlowEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getAlias() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.ALIAS);
    }
    @SuppressWarnings("unchecked") @Override public void setAlias(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.ALIAS, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getDescription() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.DESCRIPTION);
    }
    @SuppressWarnings("unchecked") @Override public void setDescription(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.DESCRIPTION, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getProviderId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.PROVIDER_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setProviderId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.PROVIDER_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isBuiltIn() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.BUILT_IN);
    }
    @SuppressWarnings("unchecked") @Override public void setBuiltIn(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.BUILT_IN, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean isTopLevel() {
        return (Boolean) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.TOP_LEVEL);
    }
    @SuppressWarnings("unchecked") @Override public void setTopLevel(Boolean p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapAuthenticationFlowEntityFields.TOP_LEVEL, p0);
    }
}
